@@ -111,6 +111,8 @@ public:
         return !m_selectedRows.isEmpty();
     }
 
+    static QString virtualScreenIdForApp(const QString &appId);
+
 public Q_SLOTS:
     void clearSelection();
 
@@ -121,3 +123,5 @@ private:
     QList<Output> m_outputs;
     QSet<quint32> m_selectedRows;
 };
+
+Q_DECLARE_OPERATORS_FOR_FLAGS(OutputsModel::Options)
